#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FUZZY_EQUAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FUZZY_EQUAL_HPP_INCLUDED

#include <nt2/fuzzy/include/functions/scalar/fuzzy_equal.hpp>

#endif
